
RiotKit Harbor 2
================

**docker-compose** based framework for building production-like environments - developing and testing on your local computer, deploying to your server or cluster from shell or from CI.
**Harbor is a pre-configured set of most popular technologies available to use with docker-compose, in addition of our exclusive features**


**Features:**

- Service discovery (pins containers into WWW domains by labelling)
- Deployment strategies: compose's standard, recreation, and **rolling-updates (zero-downtime updates)**
- Automatic Letsencrypt SSL
- Standardized directory structures and design patterns
- Ready to use snippets of code and solutions
- Ansible integration to prepare your production/testing server and deploy updates in extremely intuitive way


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   first-steps
   structure


From authors
============

Project was started as a part of RiotKit initiative, for the needs of grassroot organizations such as:

- Fighting for better working conditions syndicalist (International Workers Association for example)
- Tenants rights organizations
- Various grassroot organizations that are helping people to organize themselves without authority

.. rst-class:: language-en align-center

*RiotKit Collective*
